Change Gerrit URL for pipelines and tests

Change-Id: I809b7db74f399b418bb549aadc17659457e8c834
Related-Prod:#PROD-33788(PROD:33788)
diff --git a/jobs/pipelines/swarm-bootstrap-salt-cluster-devops.groovy b/jobs/pipelines/swarm-bootstrap-salt-cluster-devops.groovy
index e689a40..3d17dfe 100644
--- a/jobs/pipelines/swarm-bootstrap-salt-cluster-devops.groovy
+++ b/jobs/pipelines/swarm-bootstrap-salt-cluster-devops.groovy
@@ -13,7 +13,7 @@
  *   MCP_IMAGE_PATH1604            Local path to the image http://ci.mcp.mirantis.net:8085/images/ubuntu-16-04-x64-mcpproposed.qcow2
  *   IMAGE_PATH_CFG01_DAY01        Local path to the image http://ci.mcp.mirantis.net:8085/images/cfg01-day01-proposed.qcow2
  *   CFG01_CONFIG_IMAGE_NAME       Name for the creating config drive image, like cfg01.${LAB_CONFIG_NAME}-config-drive.iso
- *   TCP_QA_REFS                   Reference to the tcp-qa change on review.gerrithub.io, like refs/changes/46/418546/41
+ *   TCP_QA_REFS                   Reference to the tcp-qa change on Gerrit, like refs/changes/46/418546/41
  *   PIPELINE_LIBRARY_REF          Reference to the pipeline-library change
  *   MK_PIPELINES_REF              Reference to the mk-pipelines change
  *   COOKIECUTTER_TEMPLATE_COMMIT  Commit/tag/branch for cookiecutter-templates repository. If empty, then takes ${MCP_VERSION} value
diff --git a/jobs/pipelines/swarm-deploy-platform-without-cicd.groovy b/jobs/pipelines/swarm-deploy-platform-without-cicd.groovy
index ae46b22..d9e8cf4 100644
--- a/jobs/pipelines/swarm-deploy-platform-without-cicd.groovy
+++ b/jobs/pipelines/swarm-deploy-platform-without-cicd.groovy
@@ -9,7 +9,7 @@
  *   ENV_NAME                      Fuel-devops environment name
  *   STACK_INSTALL                 Stacks to install using Jenkins on CICD cluster: "openstack,stacklight"
  *   STACK_INSTALL_TIMEOUT         Stacks installation timeout
- *   TCP_QA_REFS                   Reference to the tcp-qa change on review.gerrithub.io, like refs/changes/46/418546/41
+ *   TCP_QA_REFS                   Reference to the tcp-qa change on Gerrit, like refs/changes/46/418546/41
  *   SHUTDOWN_ENV_ON_TEARDOWN      optional, shutdown fuel-devops environment at the end of the job
  *
  */
diff --git a/jobs/pipelines/swarm-deploy-platform.groovy b/jobs/pipelines/swarm-deploy-platform.groovy
index ca4b16c..b8afc35 100644
--- a/jobs/pipelines/swarm-deploy-platform.groovy
+++ b/jobs/pipelines/swarm-deploy-platform.groovy
@@ -9,7 +9,7 @@
  *   ENV_NAME                      Fuel-devops environment name
  *   STACK_INSTALL                 Stacks to install using Jenkins on CICD cluster: "openstack,stacklight"
  *   STACK_INSTALL_TIMEOUT         Stacks installation timeout
- *   TCP_QA_REFS                   Reference to the tcp-qa change on review.gerrithub.io, like refs/changes/46/418546/41
+ *   TCP_QA_REFS                   Reference to the tcp-qa change on Gerrit, like refs/changes/46/418546/41
  *   SHUTDOWN_ENV_ON_TEARDOWN      optional, shutdown fuel-devops environment at the end of the job
  *   MAKE_SNAPSHOT_STAGES          optional, use "dos.py snapshot" to snapshot stages
  *
diff --git a/jobs/pipelines/swarm-run-pytest.groovy b/jobs/pipelines/swarm-run-pytest.groovy
index ee341ae..f7ad7c3 100644
--- a/jobs/pipelines/swarm-run-pytest.groovy
+++ b/jobs/pipelines/swarm-run-pytest.groovy
@@ -10,7 +10,7 @@
  *   RUN_TEST_OPTS                 Pytest option -k or -m, with expression to select necessary tests. Additional pytest options are allowed.
  *   PARENT_NODE_NAME              Name of the jenkins slave to create the environment
  *   PARENT_WORKSPACE              Path to the workspace of the parent job to use tcp-qa repo
- *   TCP_QA_REFS                   Reference to the tcp-qa change on review.gerrithub.io, like refs/changes/46/418546/41
+ *   TCP_QA_REFS                   Reference to the tcp-qa change on Gerrit, like refs/changes/46/418546/41
  *   SHUTDOWN_ENV_ON_TEARDOWN      optional, shutdown fuel-devops environment at the end of the job
  *   LAB_CONFIG_NAME               Not used (backward compatibility, for manual deployment steps only)
  *   REPOSITORY_SUITE              Not used (backward compatibility, for manual deployment steps only)
diff --git a/jobs/pipelines/swarm-testrail-report.groovy b/jobs/pipelines/swarm-testrail-report.groovy
index a8af4e5..2799443 100644
--- a/jobs/pipelines/swarm-testrail-report.groovy
+++ b/jobs/pipelines/swarm-testrail-report.groovy
@@ -11,7 +11,7 @@
  *   PARENT_NODE_NAME              Name of the jenkins slave to create the environment
  *   PARENT_WORKSPACE              Path to the workspace of the parent job to use tcp-qa repo
  *   TEMPEST_TEST_SUITE_NAME       Name of tempest suite
- *   TCP_QA_REFS                   Reference to the tcp-qa change on review.gerrithub.io, like refs/changes/46/418546/41
+ *   TCP_QA_REFS                   Reference to the tcp-qa change on Gerrit, like refs/changes/46/418546/41
  */
 
 @Library('tcp-qa')_
diff --git a/src/com/mirantis/system_qa/SharedPipeline.groovy b/src/com/mirantis/system_qa/SharedPipeline.groovy
index 34049e7..18b70af 100644
--- a/src/com/mirantis/system_qa/SharedPipeline.groovy
+++ b/src/com/mirantis/system_qa/SharedPipeline.groovy
@@ -176,10 +176,10 @@
         """)
 
         run_cmd("""\
-            git clone https://github.com/Mirantis/tcp-qa.git ${env.WORKSPACE}
+            git clone https://gerrit.mcp.mirantis.com/mcp/tcp-qa ${env.WORKSPACE}
             if [ -n "$TCP_QA_REFS" ]; then
                 set -e
-                git fetch https://review.gerrithub.io/Mirantis/tcp-qa $TCP_QA_REFS && git checkout FETCH_HEAD || exit \$?
+                git fetch https://gerrit.mcp.mirantis.com/mcp/tcp-qa $TCP_QA_REFS && git checkout FETCH_HEAD || exit \$?
             fi
             pip install --upgrade --upgrade-strategy=only-if-needed -r tcp_tests/requirements.txt
         """)
@@ -190,7 +190,7 @@
         run_cmd("""\
             if [ -n "$TCP_QA_REFS" ]; then
                 set -e
-                git reset --hard && git fetch https://review.gerrithub.io/Mirantis/tcp-qa $TCP_QA_REFS && git checkout FETCH_HEAD || exit \$?
+                git reset --hard && git fetch https://gerrit.mcp.mirantis.com/mcp/tcp-qa $TCP_QA_REFS && git checkout FETCH_HEAD || exit \$?
             fi""")
         if (updateRequirements) {
             run_cmd("""\
diff --git a/tcp_tests/templates/shared-salt.yaml b/tcp_tests/templates/shared-salt.yaml
index 79abb63..d5b5d50 100644
--- a/tcp_tests/templates/shared-salt.yaml
+++ b/tcp_tests/templates/shared-salt.yaml
@@ -588,7 +588,7 @@
   cmd: |
     set -e;
     mkdir -p /root/environment/;
-    export GIT_SSL_NO_VERIFY=true; git clone https://github.com/Mirantis/environment-template /root/environment/environment_template
+    export GIT_SSL_NO_VERIFY=true; git clone https://gerrit.mcp.mirantis.com/mcp/tcp-qa-environment-template /root/environment/environment_template
 
     {%- if ENVIRONMENT_TEMPLATE_REF_CHANGE != '' %}
     pushd /root/environment/environment_template &&
diff --git a/jobs/pipelines/packer-image-create.groovy b/jobs/pipelines/packer-image-create.groovy
index 94133a7..7aa417a 100644
--- a/jobs/pipelines/packer-image-create.groovy
+++ b/jobs/pipelines/packer-image-create.groovy
@@ -20,7 +20,7 @@
  *   OS_CREDENTIALS                OpenStack username and password credentials ID in Jenkins
  *   UPLOAD_IMAGE_TO_GLANCE        If True: upload image to glance; if False: store as an artifact
 
  *   TCP_QA_REFS                   Reference to the tcp-qa change on review.gerrithub.io, like refs/changes/46/418546/41
  */
 
 @Library('tcp-qa')_
@@ -35,7 +35,7 @@
             stage("Clean the environment and clone tcp-qa") {
                 deleteDir()
                 shared.run_cmd("""\
-                    git clone https://github.com/Mirantis/tcp-qa.git ${WORKSPACE}
+                    git clone https://gerrit.mcp.mirantis.com/mcp/tcp-qa ${WORKSPACE}
                 """)
                 shared.update_working_dir(false)
                 sh "mkdir ./tmp"
@@ -20,7 +20,7 @@
  *   UPLOAD_IMAGE_TO_GLANCE        If True: upload image to glance; if False: store as an artifact
 
- *   TCP_QA_REFS                   Reference to the tcp-qa change on review.gerrithub.io, like refs/changes/46/418546/41
+ *   TCP_QA_REFS                   Reference to the tcp-qa change on Gerrit, like refs/changes/46/418546/41
  */
 
diff --git a/jobs/pipelines/swarm-bootstrap-salt-cluster-heat.groovy b/jobs/pipelines/swarm-bootstrap-salt-cluster-heat.groovy
index a4903c8..18830d8 100644
--- a/jobs/pipelines/swarm-bootstrap-salt-cluster-heat.groovy
+++ b/jobs/pipelines/swarm-bootstrap-salt-cluster-heat.groovy
@@ -13,7 +13,7 @@
  *   MCP_IMAGE_PATH1604            Local path to the image http://ci.mcp.mirantis.net:8085/images/ubuntu-16-04-x64-mcpproposed.qcow2
  *   IMAGE_PATH_CFG01_DAY01        Local path to the image http://ci.mcp.mirantis.net:8085/images/cfg01-day01-proposed.qcow2
  *   CFG01_CONFIG_IMAGE_NAME       Name for the creating config drive image, like cfg01.${LAB_CONFIG_NAME}-config-drive.iso
  *   TCP_QA_REFS                   Reference to the tcp-qa change on review.gerrithub.io, like refs/changes/46/418546/41
  *   PIPELINE_LIBRARY_REF          Reference to the pipeline-library change
  *   MK_PIPELINES_REF              Reference to the mk-pipelines change
  *   COOKIECUTTER_TEMPLATE_COMMIT  Commit/tag/branch for cookiecutter-templates repository. If empty, then takes ${MCP_VERSION} value
@@ -272,7 +272,7 @@
                 [ -d /home/jenkins/fuel-devops30 ] || virtualenv /home/jenkins/fuel-devops30
             """, true, false, true)
             shared.run_cmd("""\
-                git clone https://github.com/Mirantis/tcp-qa.git ${PARENT_WORKSPACE}
+                git clone https://gerrit.mcp.mirantis.com/mcp/tcp-qa ${PARENT_WORKSPACE}
             """)
             shared.update_working_dir()
         }
@@ -13,7 +13,7 @@
  *   IMAGE_PATH_CFG01_DAY01        Local path to the image http://ci.mcp.mirantis.net:8085/images/cfg01-day01-proposed.qcow2
  *   CFG01_CONFIG_IMAGE_NAME       Name for the creating config drive image, like cfg01.${LAB_CONFIG_NAME}-config-drive.iso
- *   TCP_QA_REFS                   Reference to the tcp-qa change on review.gerrithub.io, like refs/changes/46/418546/41
+ *   TCP_QA_REFS                   Reference to the tcp-qa change on Gerrit, like refs/changes/46/418546/41
  *   PIPELINE_LIBRARY_REF          Reference to the pipeline-library change
  *   MK_PIPELINES_REF              Reference to the mk-pipelines change